@@ -29,7 +29,7 @@ class BackendBase:
     async def cleanup_old_files(self):
         pass
 
-    async def download_file(self, url, path):
+    def download_file(self, url, path):
         result = file_fetcher.fetch_file(url, path)
         return result
 
